import os
import sys

from loguru import logger

from pylanggetter.utils import Utils

_BASE_URL: str = "http://dofusretro.cdn.ankama.com/lang/"
_BASE_DIR: str = "lang/"


def start():
    lang_list = Utils.parse_args(sys.argv)

    logger.info(f"Getting lang from this : {lang_list}")

    os.makedirs(_BASE_DIR + "swf/", exist_ok=True)

    versions_uri = _BASE_URL + "versions.swf"
    versions_dir = _BASE_DIR + "versions.swf"

    content = Utils.get_content_from_uri(versions_uri, False)
    Utils.write_content_to_file(versions_dir, content, True)

    for count_lang, lang in enumerate(lang_list, start=1):
        version_name = "versions_" + lang + ".txt"
        url_version = _BASE_URL + version_name
        dir_version = _BASE_DIR + version_name

        content = Utils.get_content_from_uri(url_version, True)
        Utils.write_content_to_file(dir_version, content, False)

        file_list = Utils.parse_version(dir_version)

        for count_file, file in enumerate(file_list, start=1):
            url_file = _BASE_URL + "swf/" + file
            dir_file = _BASE_DIR + "swf/" + file

            logger.info(
                f"[{count_lang}/{len(lang_list)}][{count_file}/{len(file_list)}] \t Get lang {file}"
            )
            content = Utils.get_content_from_uri(url_file, False)
            Utils.write_content_to_file(dir_file, content, True)



import urllib.request as urireq


class Utils:
    DEFAULT_LANG: list = ["fr", "de", "en", "it", "es", "pt", "nl"]

    @staticmethod
    def write_content_to_file(filename: str, content: str, isByte: bool) -> None:
        """Write content to the file filename

        Args:
            filename (str): the filename destination
            content (str): the content to write
            isByte (bool): true if the content is raw bytes, false otherwise
        """
        mode = "wb" if isByte else "w"
        with open(filename, mode) as file:
            file.write(content)

    @staticmethod
    def get_content_from_uri(uri: str, decode: bool) -> str:
        """Get the content of a file from the uri

        Args:
            uri (str): the url of the file
            decode (bool): true if decode the content in utf-8, false otherwise

        Returns:
            str: the content of the file
        """
        with urireq.urlopen(uri) as file:
            if decode:
                return file.read().decode("utf-8")
            return file.read()

    @staticmethod
    def parse_version(version_file: str) -> list:
        """Parse the given version file and return a list of the swf files

        Args:
            version_file (str): the version_*.txt to parse

        Returns:
            list: a list of swf file name 
        """
        with open(version_file, "r") as file:
            content = file.read()
        file_list = content.replace("&f=", "").replace(",", "_").split("|")[:-1]
        return [f"{name}.swf" for name in file_list]

    @staticmethod
    def parse_args(args: list) -> list:
        """Parse the CLI args to determine the swg lang to get

        Args:
            args (list): the list of lang to fetch

        Raises:
            ValueError: When a lang arg is not available
        
        Returns:
            list: the list of the language lang to get
        """
        args = args[1:]
        if len(args) < 1:
            return Utils.DEFAULT_LANG
            
        for arg in args:
            if arg not in Utils.DEFAULT_LANG:
                raise ValueError(f"Unknow lang {arg}, available lang : {Utils.DEFAULT_LANG}")
        return args


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pylanggetter']

package_data = \
{'': ['*']}

install_requires = \
['loguru>=0.6.0,<0.7.0']

setup_kwargs = {
    'name': 'pylanggetter',
    'version': '0.2.1',
    'description': 'Tiny utility to help you download Dofus Retro Lang files',
    'long_description': '# PyLangGetter\nTiny utility to help you download Dofus Retro Lang files.\n\n## Usage\n`python PyLangGetter.py` to get all lang files in all language \\\n`python PyLangGetter.py fr` to get lang files in **fr** language \\\n`python PylangGetter.py it de` to get lang files in **it** and **de** langage \\\nAvailable language option : `fr, de, en, it, es, pt, nl`',
    'author': 'Dysta',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Dysta/PylangGetter',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8',
}


setup(**setup_kwargs)
